==> daikon-1.0.tar.gz: daikon-1.0/src/Font.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <fstream>

#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>

#include "Font.h"

using namespace std;

Font* Font::instance = new Font();

SDL_Color Font::DEFAULTCOLOR = { 255, 255, 255, 0 };

Font::Font()
{
    if ( TTF_Init() == -1 ) {
        cerr << "TTF_Init: " << TTF_GetError() << endl;
        exit(-1);
    }
    ifstream ifs("fontpath");

    if ( ifs.fail() ) {
        cerr << "フォントのパス設定ファイルが読み込めません。" << endl;
        exit(-1);
    }

    while ( !ifs.eof() ) {
        ifs >> fontFileName;
        font = TTF_OpenFont(fontFileName.c_str(), 12);
        if ( !font ) { continue; }
        else { break; }
    }


    if ( fontFileName.empty() ) {
        cerr << "フォントが見つかりません。" << endl;
        exit(-1);
    }

    font_large = TTF_OpenFont(fontFileName.c_str(), 24);
    if ( !font_large ) {
        cerr << "TTF_OpenFont(24): " << TTF_GetError() << endl;
        exit(-1);
    }

    font_huge = TTF_OpenFont(fontFileName.c_str(), 36);
    if ( !font_huge ) {
        cerr << "TTF_OpenFont(36): " << TTF_GetError() << endl;
        exit(-1);
    }
}

==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/Font.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <fstream>

#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>
#include <boost/filesystem.hpp>

#include "Font.h"

using namespace std;

Font* Font::instance = new Font();

SDL_Color Font::DEFAULTCOLOR = { 255, 255, 255, 0 };

Font::Font() {
}

void Font::init(boost::filesystem::path fontPath) {

    instance = new Font();

    if ( TTF_Init() == -1 ) {
        cerr << "TTF_Init: " << TTF_GetError() << endl;
        exit(-1);
    }

    ifstream ifs((fontPath/"fontpath").string().c_str());

    if ( ifs.fail() ) {
        cerr << "フォントのパス設定ファイルが読み込めません。" << endl;
        cerr << "'" << fontPath << "fontpath' not found." << endl;
        exit(-1);
    }

    while ( !ifs.eof() ) {
        ifs >> instance->fontFileName;
        instance->font = TTF_OpenFont(instance->fontFileName.c_str(), 12);
        if ( !instance->font ) { continue; }
        else { break; }
    }


    if ( instance->fontFileName.empty() ) {
        cerr << "フォントが見つかりません。" << endl;
        exit(-1);
    }

    instance->font_large = TTF_OpenFont(instance->fontFileName.c_str(), 24);
    if ( !instance->font_large ) {
        cerr << "TTF_OpenFont(24): " << TTF_GetError() << endl;
        exit(-1);
    }

    instance->font_huge = TTF_OpenFont(instance->fontFileName.c_str(), 36);
    if ( !instance->font_huge ) {
        cerr << "TTF_OpenFont(36): " << TTF_GetError() << endl;
        exit(-1);
    }
}

const Font* Font::getInstance()
{
    if ( instance == NULL ) {
        cerr << "Font::init(fontPath) is first." << endl;
        exit(-1);
    }
    return Font::instance;
}

TTF_Font* Font::getDefaultFont()
{
    return getInstance()->font;
}

TTF_Font* Font::getLargeFont()
{
    return getInstance()->font_large;
}

TTF_Font* Font::getHugeFont()
{
    return getInstance()->font_huge;
}

SDL_Color* Font::getDefaultColor()
{
    return &(getInstance()->DEFAULTCOLOR);
}
